@@ -4,7 +4,7 @@ from .is_ip import is_ip
 from .utils.Classes.String import String
 from .utils.assert_string import assert_string
 
-subnet_maybe = "^\d{1,3}$"
+subnet_maybe = r"^\d{1,3}$"
 subnet_v4 = 32
 subnet_v6 = 128
 
